/*
    This file is part of MDic Dictionary

    Copyright (C) 2007-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
    Copyright (C) 2007-2010 Majid Ramezanpour <majid.ramezanpour@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/

*/

#ifndef ADDDICTIONARY_H
#define ADDDICTIONARY_H

#include <QtGui/QDialog>
#include "ui_adddictionarybase.h"
#include <dictcore.h>

class AddDictionary : public QDialog, public Ui::AddDictionaryBase
{
    Q_OBJECT
public:
    AddDictionary(QWidget* parent = 0);
    virtual void accept();
    ~AddDictionary();
    DictCore::Dictionary resultDict();

protected slots:
    void slotTypeChanged(int);
    void slotSelectDicFile();
private:
    DictCore::Dictionary m_resultDict;
    QMap<QString, QString> m_NameCode;//Language Name, Language Code
};

#endif // ADDDICTIONARY_H
